Python 2 and 3 forward-compatible for PyAPNs : https://github.com/djacobs/PyAPNs.git

Installation:

You can install PyAPNs from this repository if you want the latest version:

$ git clone https://github.com/flamewow/PyAPNs.git

$ cd PyAPNs

$ python setup.py build

Activate virtualenv (or use sudo):

$ python setup.py install 

Or you can install the latest release from PYPI:

$ pip install apns3
